rename away from RPM

The SetPoint output from a thermal PID is likely RPM, and that value is
then fed into a fan controller PID as the set-point (unit: RPM).  This
does not have to be RPM, however.  Continue renaming variables and
methods to remove the explicit unit-naming.

Signed-off-by: Patrick Venture <venture@google.com>
Change-Id: I570dee0c688338f9a458cac7123314717bee2b42
diff --git a/test/pid_fancontroller_unittest.cpp b/test/pid_fancontroller_unittest.cpp
index ad646bf..abf9aaa 100644
--- a/test/pid_fancontroller_unittest.cpp
+++ b/test/pid_fancontroller_unittest.cpp
@@ -122,21 +122,21 @@
     // Fanspeed starts are Neutral.
     EXPECT_EQ(FanSpeedDirection::NEUTRAL, fp->getFanDirection());
 
-    // getMaxRPMRequest returns a higher value than 0, so the fans should be
-    // marked as speeding up.
-    EXPECT_CALL(z, getMaxRPMRequest()).WillOnce(Return(10.0));
+    // getMaxSetPointRequest returns a higher value than 0, so the fans should
+    // be marked as speeding up.
+    EXPECT_CALL(z, getMaxSetPointRequest()).WillOnce(Return(10.0));
     EXPECT_EQ(10.0, p->setptProc());
     EXPECT_EQ(FanSpeedDirection::UP, fp->getFanDirection());
 
-    // getMaxRPMRequest returns a lower value than 10, so the fans should be
-    // marked as slowing down.
-    EXPECT_CALL(z, getMaxRPMRequest()).WillOnce(Return(5.0));
+    // getMaxSetPointRequest returns a lower value than 10, so the fans should
+    // be marked as slowing down.
+    EXPECT_CALL(z, getMaxSetPointRequest()).WillOnce(Return(5.0));
     EXPECT_EQ(5.0, p->setptProc());
     EXPECT_EQ(FanSpeedDirection::DOWN, fp->getFanDirection());
 
-    // getMaxRPMRequest returns the same value, so the fans should be marked as
-    // neutral.
-    EXPECT_CALL(z, getMaxRPMRequest()).WillOnce(Return(5.0));
+    // getMaxSetPointRequest returns the same value, so the fans should be
+    // marked as neutral.
+    EXPECT_CALL(z, getMaxSetPointRequest()).WillOnce(Return(5.0));
     EXPECT_EQ(5.0, p->setptProc());
     EXPECT_EQ(FanSpeedDirection::NEUTRAL, fp->getFanDirection());
 }